@@ -134,7 +134,7 @@ class Bitwarden(object):
                             "totp",
                             bw_item["id"],
                             "--session",
-                            bitwarden_token,
+                            self.bitwarden_token,
                         )
                         self.data[credentials_key]["otp"] = bitwarden_app.stdout
                     if "fields" in bw_item:
